.. currentmodule:: revl

.. _command_evaluation:

Command Evaluation
==================

.. autosummary::
   :nosignatures:

   Context
   run


----

.. autoclass:: Context

----

.. autofunction:: run
